translate.convert.rc2po.rc2po

Package translate :: Package convert :: Module rc2po :: Class rc2po |
[hide private]
[frames] | no frames]

# Class rc2po

source code

Convert a .rc file to a .po file for handling the translation.

Instance Methods | [hide private]
convert_store(self, input_store, duplicatestyle="msgctxt") converts a .rc file to a .po file... | source code
merge_store(self, template_store, input_store, blankmsgstr=False, duplicatestyle="msgctxt") converts two .rc files to a .po file... | source code
convert_unit(self, input_unit, commenttype) Converts a .rc unit to a .po unit. | source code

Method Details | [hide private]

### convert_unit(self, input_unit, commenttype) | source code
Converts a .rc unit to a .po unit. Returns None if empty or not for translation.